@@ -69,34 +69,28 @@ def create_blank_udic(ndim):
     """
     Create a blank universal dictionary for a spectrum of dimension ndim.
     """
-    udic = dict()
-    udic["ndim"] = ndim
+    udic = {
+        "ndim": ndim,
+    }
 
     for i in range(ndim):
-        d = dict()
-        d["sw"] = 999.99        # spectral width in Hz
-        d["complex"] = True     # Quadrature, True when dimension is complex
-        d["obs"] = 999.99       # Observation frequency in MHz
-        d["car"] = 999.99       # Carrier frequency in Hz
-        # Number of points in dimension based on the shape of the data array.
-        # As such the direct dimension (-1) size is R|I, all indirect
-        # dimensions are R+I
-        d["size"] = 1
-
-        d["label"] = ["X", "Y", "Z", "A"][i]    # name of dimension
-
-        # encoding of dimension, ie states, tppi, etc.  The direct dimension
-        # should be listed as direct.
-        if i == ndim - 1:
-            d["encoding"] = "direct"
-        else:
-            d["encoding"] = "states"
-
-        # time and freq flags for domain of dimension
-        d["time"] = True
-        d["freq"] = False
-
-        udic[i] = d
+        udic[i] = {
+            "sw": 999.99,       # spectral width in Hz
+            "complex": True,    # Quadrature, True when dimension is complex
+            "obs": 999.99,      # Observation frequency in MHz
+            "car": 999.99,      # Carrier frequency in Hz
+            # Number of points in dimension based on the shape of the data array.
+            # As such the direct dimension (-1) size is R|I, all indirect
+            # dimensions are R+I
+            "size": 1,
+            "label": ["X", "Y", "Z", "A"][i],   # name of dimension
+            # encoding of dimension, ie states, tppi, etc.  The direct dimension
+            # should be listed as direct.
+            "encoding": "direct" if i == ndim - 1 else "states",
+            # time and freq flags for domain of dimension
+            "time": True,
+            "freq": False,
+        }
 
     return udic
 
@@ -459,7 +453,7 @@ def open_towrite(filename, overwrite=False, mode='wb'):
     Open filename for writing and return file object
 
     Function checks if file exists (and raises IOError if overwrite=False) and
-    creates necessary directiories as needed.
+    creates necessary directories as needed.
     """
     # check if file exists and overwrite if False
     if os.path.exists(filename) and (overwrite is False):
@@ -526,7 +520,7 @@ def trace2index_flat(shape, ntrace):
     """
     Calculate the index of a trace assuming a flat structure
     """
-    # algorithm is to take quotient/remainers of sizes in reverse
+    # algorithm is to take quotient/remainders of sizes in reverse
     q = ntrace  # seed quotient with remained
     index = []
     for s in shape[:0:-1]:  # loop from last size to 2nd size
@@ -545,7 +539,7 @@ def index2trace_opp(shape, index):
     # deal with the phase component
     phases = [v % 2 for v in index]
     nphase = index2trace_flat([2] * n, phases[::-1])
-    # deal with the remainer
+    # deal with the remainder
     pindex = [v // 2 for v in index]
     pshape = [i // 2 for i in shape]
     nbase = index2trace_flat(pshape, pindex)
@@ -575,7 +569,7 @@ def index2trace_reg(shape, index):
     # deal with the phase component
     phases = [v % 2 for v in index]
     nphase = index2trace_flat([2] * n, phases)
-    # deal with the remainer
+    # deal with the remainder
     pindex = [v // 2 for v in index]
     pshape = [i // 2 for i in shape]
     nbase = index2trace_flat(pshape, pindex)
@@ -657,7 +651,7 @@ class data_nd(object):
         pass
 
     def __setdimandshape__(self):
-        """ Set the the ndim and shape attributes from fshape """
+        """ Set the ndim and shape attributes from fshape """
         # set ndim and shape
         self.ndim = len(self.fshape)
         self.shape = tuple([self.fshape[i] for i in self.order])
